mailr14777 - /1.3/gui/menu.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on October 04, 2011 - 18:28:
Author: bugman
Date: Tue Oct  4 18:28:36 2011
New Revision: 14777

URL: http://svn.gna.org/viewcvs/relax?rev=14777&view=rev
Log:
Renamed the 'Settings' menu to 'Tools'.

This is to make it more general for the future inclusion of the test suite.


Modified:
    1.3/gui/menu.py

Modified: 1.3/gui/menu.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/menu.py?rev=14777&r1=14776&r2=14777&view=diff
==============================================================================
--- 1.3/gui/menu.py (original)
+++ 1.3/gui/menu.py Tue Oct  4 18:28:36 2011
@@ -52,7 +52,7 @@
     MENU_VIEW_RESULTS = wx.NewId()
     MENU_VIEW_PIPE_EDIT = wx.NewId()
     MENU_VIEW_PROMPT = wx.NewId()
-    MENU_SETTINGS_FORMAT = wx.NewId()
+    MENU_TOOLS_FORMAT = wx.NewId()
     MENU_HELP_MANUAL = wx.NewId()
     MENU_HELP_MAIL = wx.NewId()
     MENU_HELP_REFS = wx.NewId()
@@ -110,13 +110,13 @@
         # The 'User functions' menu entries.
         self._user_functions()
 
         # The 'Settings' menu entries.
         menu = wx.Menu()
-        menu.AppendItem(build_menu_item(menu, id=self.MENU_SETTINGS_FORMAT, 
text="&Free file format settings", icon=paths.icon_16x16.document_properties))
-        self.menubar.Append(menu, "&Settings")
-
-        # The 'Settings' menu actions.
-        self.gui.Bind(wx.EVT_MENU, self.gui.free_file_format_settings, 
id=self.MENU_SETTINGS_FORMAT)
+        menu.AppendItem(build_menu_item(menu, id=self.MENU_TOOLS_FORMAT, 
text="&Free file format settings", icon=paths.icon_16x16.document_properties))
+        self.menubar.Append(menu, "&Tools")
+
+        # The 'Tools' menu actions.
+        self.gui.Bind(wx.EVT_MENU, self.gui.free_file_format_settings, 
id=self.MENU_TOOLS_FORMAT)
 
         # The 'Help' menu entries.
@@ -110,13 +110,13 @@
         self._user_functions()
 
-        # The 'Settings' menu entries.
+        # The 'Tools' menu entries.
         menu = wx.Menu()
         menu = wx.Menu()




Related Messages


Powered by MHonArc, Updated Tue Oct 04 19:40:02 2011